..
    This file is part of Invenio.
    Copyright (C) 2016-2023 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.



Changes
=======

Version 2.0.0a2 (released 2023-10-12)

- make config overridable

Version 2.0.0a1 (released 2023-05-03)

- upgrade xrootdpyfs dependency

Version 1.0.0a6 (released 2017-08-30)

- Initial public release.
